==> deepin-home_1.6.0.tar.xz: BUILD/translations/deepin-home/de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>My Favorites</source>
        <translation>Meine Favoriten</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Meine Rückmeldungen</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 Aufrufe</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Kommend</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Offizielle Antwort</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Neueste</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Kommunikation</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Diskutieren und teilen Sie hier</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Fehlerbericht</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Melden Sie gefundene Probleme</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Reichen Sie Ihre Vorschläge ein</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Ressourcen</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Fragebogen</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Mitmachen</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Interne Tests</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Gemeinschaftsnachrichten</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>Messages</source>
        <translation>Nachrichten</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Fragebogen</translation>
    </message>
    <message>
        <source>No more items</source>
        <translation>Keine weiteren Elemente</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Beim Systemstart starten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Noch keine Nachrichten.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 Nachrichten</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Alle als gelesen markieren</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Mehr anzeigen</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Auffrischen</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Noch keine Fragebögen.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Abgelaufen am: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Ausfüllen</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Ausstehend</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bestätigt</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Antwortete</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Gelöst</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Wird geprüft</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Angenommen</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Abgeschlossen</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Rückmeldung absenden</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type：</source>
        <translation>Typ：</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Fehlerbericht</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Titel：</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Content：</source>
        <translation>Inhalt：</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-Mail：</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Systemversion:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Geräte-Info：</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Bildschirmfotos：</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Bilddateien</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Absenden</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Geräteinformationen</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Meine Rückmeldungen</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Meine Favoriten</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-home_1.6.4.tar.xz: BUILD/translations/deepin-home/de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Bitte melden Sie sich mit Ihrer Deepin-ID an.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Für die nachfolgenden Handlungen müssen Sie sich anmelden.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Sie haben zu viele Anfragen gestellt. Bitte versuchen Sie es später wieder.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Für die nachfolgenden Handlungen müssen Sie sich anmelden.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Netzwerkfehler, bitte versuchen Sie es später.</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Nicht angemeldet</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Meine Favoriten</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Meine Rückmeldungen</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Anmelden</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 Aufrufe</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Aus &apos;Favoriten&apos; entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Als Favorit markieren</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Als nicht dringlich markieren</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Als dringlich markieren</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Kommend</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Offizielle Antwort</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Sortierung:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Neueste</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>dringlich</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Kommunikation</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Diskutieren und teilen Sie hier</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Fehlerbericht</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Melden Sie gefundene Probleme</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Reichen Sie Ihre Vorschläge ein</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Ressourcen</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Fragebogen</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Mitmachen</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Interne Tests</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Community News</source>
        <translation>Gemeinschaftsnachrichten</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Keine weiteren Elemente</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Nachrichten</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Fragebogen</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Beim Systemstart starten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Schnellanmeldung zu Foren, Vorschläge unterbreiten und Fehler berichten</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Noch keine Nachrichten.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 Nachrichten</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Alle als gelesen markieren</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Mehr anzeigen</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Netzwerkfehler, bitte versuchen Sie es später.</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Auffrischen</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Noch keine Fragebögen.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Abgelaufen am: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Ausfüllen</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Ausstehend</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Am reproduzieren</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bestätigt</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Antwortete</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Gelöst</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Wird geprüft</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Angenommen</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Abgeschlossen</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Dieser Fall wurde noch nicht bearbeitet und wird nicht in der öffentlichen Liste angezeigt.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Der Grund wurde noch nicht gefunden; weitere Beobachtung und Untersuchungen sind nötig.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Der Fall konnte reproduziert werden und das zugrundliegende Problem identifiziert.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Dieser Fall ist kein Fehler oder ist von anderer Natur.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Dieser Fall wurde gelöst und es steht eine Veröffentlichung an.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Die Anforderung wurde noch nicht bearbeitet und wird nicht in der öffentlichen Liste angezeigt</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Der Fall wurde anerkannt und wird intern weiterverfolgt.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Für ein zukünftiges Release vorgesehen</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Die Anforderung wurde nicht angenommen oder kann nicht zugeordnet werden</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Die Entwicklung ist abgeschlossen und steht für ein Release an.</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Bildschirmfoto konnte nicht hinzugefügt werden.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>Die Bildgröße sollte weniger als 1MB betragen.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Dieses Bildformat kann nicht hochgeladen werden.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Aktueller Status]: 
[Gewünschter Status]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Voraussetzungen]: 
[Nachzuvollziehende Schritte]: 
[Erwartete Ergebnise]: 
[Tatsächliche Ergebnisse]: </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Rückmeldung absenden</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Typ：</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Vorschläge</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Fehlerbericht</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Titel：</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Bitte beschreiben Sie kurz ihr Anliegen</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Inhalt：</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Bitte geben Sie nicht mehrere Fälle in einer Rückmeldung an</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Bitte geben Sie nicht mehrere Fälle in einer Rückmeldung an</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-Mail：</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Bitte geben Sie ihre E-Mail-Adresse an</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Systemversion:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Geräte-Info：</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Lade &lt;a href=&apos;home://sysinfo&apos;&gt;Geräteinformation&lt;/a&gt; hoch</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Bildschirmfotos：</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Bilddateien</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Ziehen Sie Dateien hierher oder klicken Sie auf den Button um bis zu drei Bilder hochzuladen</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Sind Sie sicher, dass Sie die Rückmeldungseingabe verlassen wollen?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Der Inhalt ihrer Rückmeldung wird nicht gespeichert.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Absenden</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Rückmeldung konnte nicht übertragen werden.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Bitte geben Sie einen Titel und den Inhalt ihrer Rückmeldung an</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Bitte geben Sie einen Titel ihrer Rückmeldung an</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Bitte geben Sie den Inhalt ihrer Rückmeldung an</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Fehlerhafte E-Mail-Adresse eingegeben.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Geräteinformationen</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Rückmeldungszentrale</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Meine Rückmeldungen</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Meine Favoriten</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Meine Dringlichen</translation>
    </message>
</context>
</TS>
